summaryrefslogtreecommitdiffstats
path: root/lib/Service/ItemService.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Service/ItemService.php')
-rw-r--r--lib/Service/ItemService.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/Service/ItemService.php b/lib/Service/ItemService.php
index 882e875c5..58533cb7d 100644
--- a/lib/Service/ItemService.php
+++ b/lib/Service/ItemService.php
@@ -329,9 +329,9 @@ class ItemService extends Service
/**
* @param string $userId from which user the items should be taken
* @return int of items which are starred or unread
*/
- public function getUnreadOrStarred($userId)
+ public function getUnreadOrStarred($userId): array
{
return $this->oldItemMapper->findAllUnreadOrStarred($userId);
}
@@ -329,9 +329,9 @@ class ItemService extends Service
/**
* @param string $userId from which user the items should be taken
- * @return int of items which are starred or unread
+ * @return array of items which are starred or unread
*/